@@ -159,7 +159,8 @@ class GridBase():
 
     if len(self.grid_rewards) > 0: 
       # use the pre-calculated rewards
-      return self.grid_rewards[x,y]
+      # - note this holds the rewards as row,col so must swap x and y   
+      return self.grid_rewards[y,x]
 
     # the terminal state has a reward of zero
     if (x == self.end[0]) and (y == self.end[1]):
